@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -27,7 +27,7 @@ sub new {
 	    } else {
 		$options = $arg;
 	    }
-	} elsif ($arg =~ m{^(apt-get|aptitude|pkg|yum)$}) { # XXX are there more package installers?
+	} elsif ($arg =~ m{^(apt-get|aptitude|pkg|yum|chocolatey)$}) { # XXX are there more package installers?
 	    $installer = $1;
 	} elsif ($arg eq 'batch') {
 	    $batch = 1;
@@ -104,6 +104,8 @@ sub new {
 	    } else {
 		die __PACKAGE__ . " has no support for linux distribution $linuxdistro $linuxdistroversion\n";
 	    }
+	} elsif( $os eq 'MSWin32' ) {
+	    $installer = 'chocolatey';
 	} else {
 	    die __PACKAGE__ . " has no support for operating system $os\n";
 	}
@@ -156,9 +158,10 @@ sub post_get {
 		    warn "DRYRUN: @$cmd\n";
 		} else {
 		    warn "INFO: run @$cmd...\n";
+
 		    system @$cmd;
 		    if ($? != 0) {
-			die "@$cmd failed, stop installation";
+		    	die "@$cmd failed, stop installation";
 		    }
 		}
 	    }
@@ -230,6 +233,18 @@ sub _is_linux_fedora_like {
     $linuxdistro =~ m{^(fedora|redhat|centos)$};
 }
 
+# Run a process in an elevated window, wait for its exit
+sub _win32_run_elevated {
+    my($exe, @args) = @_;
+    
+    my $args = join " ", map { if(/[ "]/) { s!"!\\"!g; qq{"$_"} } else { $_ }} @args;
+
+    my $ps1 = sprintf q{powershell -NonInteractive -NoProfile -Command "$process = Start-Process '%s' -PassThru -ErrorAction Stop -ArgumentList '%s' -Verb RunAs -Wait; Exit $process.ExitCode"},
+        $exe, $args;
+
+    $ps1;
+}
+
 sub _debug {
     my $self = shift;
     if ($self->{debug}) {
@@ -352,7 +367,6 @@ sub _find_missing_deb_packages {
 	}
     }
     waitpid $pid, 0;
-
     for my $package (@packages) {
 	if (!$seen_packages{$package}) {
 	    push @missing_packages, $package;
@@ -389,6 +403,16 @@ sub _filter_uninstalled_packages {
 	    }
 	}
 	@packages = @missing_packages;
+    } elsif ($self->{os} eq 'MSWin32') {
+	my %installed_packages = map {
+	        /^(.*)\|(.*)$/
+		    or next;
+		$1 => $2
+	    } grep {
+	        /^(.*)\|(.*)$/
+	    } `$self->{installer} list --localonly --limit-output`;
+	my @missing_packages = grep { ! $installed_packages{ $_ }} @packages;
+	@packages = @missing_packages;
     } else {
 	warn "check for installed packages is NYI for $self->{os}/$self->{linuxdistro}";
     }
@@ -406,12 +430,18 @@ sub _install_packages_commands {
     if ($self->{batch}) {
 	if ($self->{installer} =~ m{^(apt-get|aptitude)$}) {
 	    push @install_cmd, '-y';
+	} elsif ($self->{installer} eq 'pkg') { # FreeBSD's pkg
+	    # see below
 	} else {
 	    warn "batch=1 NYI for $self->{installer}";
 	}
     } else {
 	if ($self->{installer} =~ m{^(apt-get|aptitude)$}) {
 	    @pre_cmd = ('sh', '-c', 'echo -n "Install package(s) '."@packages".'? (y/N) "; read yn; [ "$yn" = "y" ]');
+	} elsif ($self->{installer} eq 'pkg') { # FreeBSD's pkg
+	    # see below
+	} elsif ($self->{installer} =~ m{^(chocolatey)$}) {
+	    # Nothing to do here
 	} else {
 	    warn "batch=0 NYI for $self->{installer}";
 	}
@@ -420,7 +450,17 @@ sub _install_packages_commands {
     if ($self->{batch} && $self->{installer} eq 'pkg') {
 	push @install_cmd, '-y';
     }
+
+    if ($self->{batch} && $self->{installer} eq 'chocolatey') {
+	push @install_cmd, '-y';
+    }
+
     push @install_cmd, @packages;
+    
+    if ($self->{os} eq 'MSWin32') {
+        # Wrap the thing in our small powershell program
+        @install_cmd = _win32_run_elevated(@install_cmd);
+    };
 
     ((@pre_cmd ? \@pre_cmd : ()), \@install_cmd);
 }
@@ -446,7 +486,9 @@ B<CPAN::Plugin::Sysdeps> is a plugin for L<CPAN.pm|CPAN> to install
 non-CPAN dependencies automatically. Currently, the list of required
 system dependencies is maintained in a static data structure in
 L<CPAN::Plugin::Sysdeps::Mapping>. Supported operations systems and
-distributions are FreeBSD and Debian-like Linux distributions.
+distributions are FreeBSD and Debian-like Linux distributions. There
+are also some module rules for Fedora-like Linux distributions and
+Windows through chocolatey.
 
 The plugin may be configured like this:
 
@@ -576,6 +618,54 @@ specify alternatives in the form C<package1 | package2 | ...>.
 
 =back
 
+=head1 USE CASES
+
+=head2 CPAN TESTERS
+
+Install system packages automatically while testing CPAN modules. If
+the smoke system runs under an unprivileged user, then a sudoers rule
+has to be added. For such a user named C<cpansand> on a Debian-like
+system this could look like this (two rules for batch and non-batch
+mode):
+
+    cpansand ALL=(ALL) NOPASSWD: /usr/bin/apt-get -y install *
+    cpansand ALL=(ALL) NOPASSWD: /usr/bin/apt-get install *
+
+=head2 USE WITHOUT CPAN.PM
+
+It's possible to use this module also without CPAN.pm through the
+L<cpan-sysdeps> script.
+
+For example, just list the system prereqs for L<Imager> on a FreeBSD
+system:
+
+    $ cpan-sysdeps --cpanmod Imager
+    freetype2
+    giflib-nox11
+    png
+    tiff
+    jpeg
+
+On a Debian system the output will look like:
+
+    libfreetype6-dev
+    libgif-dev
+    libpng12-dev
+    libjpeg-dev
+    libtiff5-dev
+
+Just show the packages which are yet uninstalled:
+
+    $ cpan-sysdeps --cpanmod Imager --uninstalled
+
+Show what L<CPAN::Plugin::Sysdeps> would execute if it was run:
+
+    $ cpan-sysdeps --cpanmod Imager --dryrun
+
+And actually run and install the missing packages:
+
+    $ cpan-sysdeps --cpanmod Imager --run
+
 =head1 NOTES, LIMITATIONS, BUGS, TODO
 
 =over
@@ -624,11 +714,6 @@ The default mapping has support for FreeBSD and Debian-like systems
 (but details are missing for distributions like Ubuntu or Mint).
 Support for other systems is missing.
 
-=item * Windows support
-
-Probably it is possible to support Windows by using installer tools
-like chocolatey.
-
 =back
 
 =head1 CREDITS
@@ -663,6 +748,10 @@ L<https://metacpan.org/author/RSAVAGE> Ron Savage,
 L<https://metacpan.org/author/ITCHARLIE> Charlie Gonzalez,
 L<https://twitter.com/jscook2345> Justin Cook.
 
+=head1 CONTRIBUTORS
+
+Max Maischein (CORION) - Windows/chocolatey support
+
 =head1 AUTHOR
 
 Slaven Rezic
